@@ -31,7 +31,7 @@ class MarkdownConverter:
 
     def format_markdown(self, markdown_text):
         """
-        简化Markdown格式处理，只处理基本格式问题
+        简化Markdown格式处理，优化多层列表嵌套支持
         
         Args:
             markdown_text (str): 原始Markdown文本
@@ -42,6 +42,9 @@ class MarkdownConverter:
         lines = markdown_text.split('\n')
         processed_lines = []
         
+        # 跟踪列表嵌套级别
+        list_levels = []
+        
         for i, line in enumerate(lines):
             line = line.rstrip()  # 移除行尾空白
             
@@ -71,16 +74,26 @@ class MarkdownConverter:
             
             # 特殊处理：对于以数字开头且后面是粗体的行，进行转义
             # 避免被Markdown库误识别为有序列表项
-            if re.match(r'^\s*\d+\.\s*\*\*', line):
-                # 转义数字点号，使其不被识别为列表项
-                line = re.sub(r'^(\s*)(\d+)\.(\s*\*\*)', r'\1\2\\.\3', line)
+            # if re.match(r'^\s*\d+\.\s*\*\*', line):
+            #     # 转义数字点号，使其不被识别为列表项
+            #     line = re.sub(r'^(\s*)(\d+)\.(\s*\*\*)', r'\1\2\\.\3', line)
                 
-                # 确保转义后的行后面有适当的换行，避免HTML结构问题
-                if i + 1 < len(lines) and re.match(r'^\s*\-\s*\*\*', lines[i + 1]):
-                    line = line + '\n\n'  # 添加两个换行，确保正确的HTML结构
+            #     # 确保转义后的行后面有适当的换行，避免HTML结构问题
+            #     if i + 1 < len(lines) and re.match(r'^\s*\-\s*\*\*', lines[i + 1]):
+            #         line = line + '\n\n'  # 添加两个换行，确保正确的HTML结构
             
-            processed_lines.append(line)
-        
+            # 计算当前行的缩进级别
+            line_stripped = line.lstrip()
+            indent_count = len(line) - len(line_stripped)
+            # print(f"line: {line}，indent_count: {indent_count}")
+            if indent_count > 0 :
+                indent_count = indent_count * 2
+            # 保持原有缩进级别，不要翻倍，避免过度缩进
+                tab_indent = ' ' * indent_count
+                a = tab_indent + line_stripped
+                processed_lines.append(a)
+            else:
+                processed_lines.append(line)
         return '\n'.join(processed_lines)
 
     def to_html(self):
@@ -131,7 +144,6 @@ class MarkdownConverter:
                         li_content = f'{before_list}\n{list_part}'
                     else:
                         li_content = list_part
-                
                 # 确保<li>标签的开始和结束在一行，但保留嵌套列表的换行
                 # 先压缩所有空白字符
                 li_content = re.sub(r'\s+', ' ', li_content)
@@ -157,9 +169,10 @@ class MarkdownConverter:
                 # 创建列表项段落
                 paragraph = doc.add_paragraph()
                 
-                # 设置缩进级别
-                if level > 0:
-                    paragraph.paragraph_format.left_indent = Inches(0.5 * level)
+                # 设置缩进级别：按层级递增缩进
+                if level > 0:  # 第二层及以上都缩进
+                    paragraph.paragraph_format.left_indent = Inches(0.2 * level)
+                # 第一层（level=0）不设置缩进
                 
                 # 手动添加序号
                 run = paragraph.add_run(f"{i}. ")
@@ -173,13 +186,34 @@ class MarkdownConverter:
                 # 创建列表项段落
                 paragraph = doc.add_paragraph(style=list_style)
                 
-                # 设置缩进级别
-                if level > 0:
-                    paragraph.paragraph_format.left_indent = Inches(0.5 * level)
+                # 设置缩进级别：按层级递增缩进
+                if level > 0:  # 第二层及以上都缩进
+                    paragraph.paragraph_format.left_indent = Inches(0.2 * level)
+                # 第一层（level=0）不设置缩进
                 
                 # 处理li的所有内容，包括文本和嵌套列表
                 self._process_li_word_content(paragraph, li, list_style, level, doc)
 
+    def _process_paragraph_content(self, paragraph, p_tag):
+        """处理p标签内容（Word文档生成）"""
+        # 处理p标签的所有子元素
+        for child in p_tag.children:
+            if hasattr(child, 'name'):
+                if child.name == 'strong':
+                    # 处理粗体文本
+                    run = paragraph.add_run(child.get_text())
+                    run.bold = True
+                else:
+                    # 处理其他标签
+                    text = child.get_text().strip()
+                    if text:
+                        paragraph.add_run(text)
+            elif isinstance(child, NavigableString) and child.strip():
+                # 处理纯文本，去除前后空白
+                text = child.strip()
+                if text:
+                    paragraph.add_run(text)
+
     def _process_li_word_content(self, paragraph, li_tag, parent_style, level=0, doc=None):
         """处理li标签内容（Word文档生成）"""
         # 处理li标签的所有子元素
@@ -196,10 +230,14 @@ class MarkdownConverter:
                     self._process_nested_list_separate(child, nested_style, level + 1, doc)
                 else:
                     # 处理其他标签
-                    paragraph.add_run(child.get_text())
+                    text = child.get_text().strip()
+                    if text:
+                        paragraph.add_run(text)
             elif isinstance(child, NavigableString) and child.strip():
-                # 处理纯文本
-                paragraph.add_run(child.strip())
+                # 处理纯文本，去除前后空白
+                text = child.strip()
+                if text:
+                    paragraph.add_run(text)
 
     def _process_nested_list_separate(self, list_tag, parent_style, level, doc):
         """处理嵌套列表（单独段落）"""
@@ -211,40 +249,28 @@ class MarkdownConverter:
                 # 创建新的段落
                 paragraph = doc.add_paragraph()
                 
-                # 设置段落缩进
-                paragraph.paragraph_format.left_indent = Inches(0.5 * level)
-                paragraph.paragraph_format.first_line_indent = Inches(0)
+                # 设置悬挂缩进，确保列表符号和文字都能正确显示
+                paragraph.paragraph_format.first_line_indent = Inches(-0.2)
+                paragraph.paragraph_format.left_indent = Inches(0.2 * level + 0.2)
                 
                 # 手动添加序号
                 run = paragraph.add_run(f"{i}. ")
                 run.bold = False
                 
-                # 处理列表项内容
+                # 处理列表项内容（不包含嵌套列表，因为嵌套列表会在_process_li_word_content中处理）
                 self._process_li_word_content(paragraph, li, parent_style, level, doc)
-                
-                # 递归处理更深层的嵌套列表
-                for child in li.children:
-                    if hasattr(child, 'name') and child.name in ['ul', 'ol']:
-                        nested_style = 'ListBullet' if child.name == 'ul' else 'ListNumber'
-                        self._process_nested_list_separate(child, nested_style, level + 1, doc)
         else:
             # 无序列表保持原有逻辑
             for li in list_tag.find_all('li', recursive=False):
                 # 创建新的段落
                 paragraph = doc.add_paragraph(style=parent_style)
                 
-                # 设置段落缩进
-                paragraph.paragraph_format.left_indent = Inches(0.5 * level)
-                paragraph.paragraph_format.first_line_indent = Inches(0)
+                # 设置悬挂缩进，确保列表符号和文字都能正确显示
+                paragraph.paragraph_format.first_line_indent = Inches(-0.2)
+                paragraph.paragraph_format.left_indent = Inches(0.2 * level + 0.2)
                 
-                # 处理列表项内容
+                # 处理列表项内容（不包含嵌套列表，因为嵌套列表会在_process_li_word_content中处理）
                 self._process_li_word_content(paragraph, li, parent_style, level, doc)
-                
-                # 递归处理更深层的嵌套列表
-                for child in li.children:
-                    if hasattr(child, 'name') and child.name in ['ul', 'ol']:
-                        nested_style = 'ListBullet' if child.name == 'ul' else 'ListNumber'
-                        self._process_nested_list_separate(child, nested_style, level + 1, doc)
 
     def to_word(self,file_name):
         """
@@ -262,7 +288,8 @@ class MarkdownConverter:
         font.name = 'SimSun'
         font.size = Pt(12)
         soup = BeautifulSoup(self.html_content, 'html.parser')
-        for tag in soup.find_all(['h1', 'h2', 'h3', 'h4','h5','h6', 'p', 'table','img','ul','ol']):
+        # 只处理顶层的标签，避免重复处理嵌套列表
+        for tag in soup.find_all(['h1', 'h2', 'h3', 'h4','h5','h6', 'p', 'table','img','ul','ol'], recursive=False):
             if tag.name == 'h1':
                 heading = doc.add_heading(level=1)
                 heading.alignment = WD_PARAGRAPH_ALIGNMENT.CENTER
@@ -297,8 +324,11 @@ class MarkdownConverter:
                 run.font.size = Pt(14)
             elif tag.name == 'p':
                 paragraph = doc.add_paragraph()
-                run = paragraph.add_run(tag.get_text())
-                run.font.size = Pt(12)
+                # 处理p标签内的所有子元素，支持strong等内联标签
+                self._process_paragraph_content(paragraph, tag)
+                # 设置段落字体大小
+                for run in paragraph.runs:
+                    run.font.size = Pt(12)
             elif tag.name == 'img':
                 img_src = tag.get('src')
                 if img_src:
